@@ -2,8 +2,9 @@ from django.contrib import admin
 from django.urls.base import reverse
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
-from edc_model_admin import SimpleHistoryAdmin, audit_fieldset_tuple
+from django_audit_fields.admin import audit_fieldset_tuple
 from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
+from edc_model_admin.history import SimpleHistoryAdmin
 
 from ..admin_site import edc_action_item_admin
 from ..forms import ActionItemForm
