@@ -17,5 +17,7 @@ class ActionItemModelAdminMixin:
 
     def get_search_fields(self, request) -> Tuple[str, ...]:
         search_fields = super().get_search_fields(request)
-        custom_fields = ("subject_identifier", "action_identifier", "tracking_identifier")
+        custom_fields = ("action_identifier",)
+        if "subject_identifier" in self.model._meta.fields:
+            custom_fields = ("subject_identifier",) + custom_fields
         return tuple(set(custom_fields + search_fields))
